==> vscat-1.0.0.tgz: package/tests/highlighting/sources/json/npm-package/results/output.quiet-light.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test quiet-light theme 1`] = `
Object {
  "lines": Array [
    "[48;2;245;245;245m [38;2;109;112;91m 1 │ [39m[38;2;119;119;119m{[39m                                                                         [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 2 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mname[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39mtest-package[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 3 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mdescription[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39mSome[39m[38;2;170;170;170m·[39m[38;2;68;140;39museful[39m[38;2;170;170;170m·[39m[38;2;68;140;39mpackage[39m[38;2;170;170;170m·[39m[38;2;68;140;39mto[39m[38;2;170;170;170m·[39m[38;2;68;140;39mdo[39m[38;2;170;170;170m·[39m[38;2;68;140;39msome[39m[38;2;170;170;170m·[39m[38;2;68;140;39museful[39m[38;2;170;170;170m·[39m[38;2;68;140;39mstuff[39m[38;2;170;170;170m·[39m[38;2;68;140;39mwith[39m[38;2;170;170;170m·[39m[38;2;68;140;39madvanc[39m[38;2;68;140;39m…[39m[49m",
    "[48;2;245;245;245m [38;2;109;112;91m 4 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mversion[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m1.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                     [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 5 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mprivate[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;156;93;39mtrue[39m[38;2;119;119;119m,[39m                                                        [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 6 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mlicense[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39mMIT[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                       [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 7 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mdependencies[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m{[39m                                                       [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 8 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-1[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m1.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 9 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-2[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m2.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m10 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-3[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m3.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m11 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-4[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m4.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m12 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-5[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m5.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m13 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-6[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m6.0.0[39m[38;2;119;119;119m\\"[39m                                                  [49m",
    "[48;2;245;245;245m [38;2;109;112;91m14 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m}[39m                                                                       [49m",
    "[48;2;245;245;245m [38;2;109;112;91m15 │ [39m[38;2;119;119;119m}[39m                                                                         [49m",
    "[48;2;245;245;245m [38;2;109;112;91m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #777777 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #333333 │   
 1 │  2, 3 │ #777777 │ \\"
 1 │  3, 7 │ #9C5D27 │ name
 1 │  7, 8 │ #777777 │ \\"
 1 │  8, 9 │ #777777 │ :
 1 │  9,10 │ #333333 │  
 1 │ 10,11 │ #777777 │ \\"
 1 │ 11,23 │ #448C27 │ test-package
 1 │ 23,24 │ #777777 │ \\"
 1 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #333333 │   
 2 │  2, 3 │ #777777 │ \\"
 2 │  3,14 │ #9C5D27 │ description
 2 │ 14,15 │ #777777 │ \\"
 2 │ 15,16 │ #777777 │ :
 2 │ 16,17 │ #333333 │  
 2 │ 17,18 │ #777777 │ \\"
 2 │ 18,89 │ #448C27 │ Some useful package to do some useful stuff with advanced capabilities.
 2 │ 89,90 │ #777777 │ \\"
 2 │ 90,91 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #333333 │   
 3 │  2, 3 │ #777777 │ \\"
 3 │  3,10 │ #9C5D27 │ version
 3 │ 10,11 │ #777777 │ \\"
 3 │ 11,12 │ #777777 │ :
 3 │ 12,13 │ #333333 │  
 3 │ 13,14 │ #777777 │ \\"
 3 │ 14,19 │ #448C27 │ 1.0.0
 3 │ 19,20 │ #777777 │ \\"
 3 │ 20,21 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #333333 │   
 4 │  2, 3 │ #777777 │ \\"
 4 │  3,10 │ #9C5D27 │ private
 4 │ 10,11 │ #777777 │ \\"
 4 │ 11,12 │ #777777 │ :
 4 │ 12,13 │ #333333 │  
 4 │ 13,17 │ #9C5D27 │ true
 4 │ 17,18 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #333333 │   
 5 │  2, 3 │ #777777 │ \\"
 5 │  3,10 │ #9C5D27 │ license
 5 │ 10,11 │ #777777 │ \\"
 5 │ 11,12 │ #777777 │ :
 5 │ 12,13 │ #333333 │  
 5 │ 13,14 │ #777777 │ \\"
 5 │ 14,17 │ #448C27 │ MIT
 5 │ 17,18 │ #777777 │ \\"
 5 │ 18,19 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #333333 │   
 6 │  2, 3 │ #777777 │ \\"
 6 │  3,15 │ #9C5D27 │ dependencies
 6 │ 15,16 │ #777777 │ \\"
 6 │ 16,17 │ #777777 │ :
 6 │ 17,18 │ #333333 │  
 6 │ 18,19 │ #777777 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #333333 │     
 7 │  4, 5 │ #777777 │ \\"
 7 │  5,14 │ #9C5D27 │ package-1
 7 │ 14,15 │ #777777 │ \\"
 7 │ 15,16 │ #777777 │ :
 7 │ 16,17 │ #333333 │  
 7 │ 17,18 │ #777777 │ \\"
 7 │ 18,23 │ #448C27 │ 1.0.0
 7 │ 23,24 │ #777777 │ \\"
 7 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #333333 │     
 8 │  4, 5 │ #777777 │ \\"
 8 │  5,14 │ #9C5D27 │ package-2
 8 │ 14,15 │ #777777 │ \\"
 8 │ 15,16 │ #777777 │ :
 8 │ 16,17 │ #333333 │  
 8 │ 17,18 │ #777777 │ \\"
 8 │ 18,23 │ #448C27 │ 2.0.0
 8 │ 23,24 │ #777777 │ \\"
 8 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #333333 │     
 9 │  4, 5 │ #777777 │ \\"
 9 │  5,14 │ #9C5D27 │ package-3
 9 │ 14,15 │ #777777 │ \\"
 9 │ 15,16 │ #777777 │ :
 9 │ 16,17 │ #333333 │  
 9 │ 17,18 │ #777777 │ \\"
 9 │ 18,23 │ #448C27 │ 3.0.0
 9 │ 23,24 │ #777777 │ \\"
 9 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #333333 │     
10 │  4, 5 │ #777777 │ \\"
10 │  5,14 │ #9C5D27 │ package-4
10 │ 14,15 │ #777777 │ \\"
10 │ 15,16 │ #777777 │ :
10 │ 16,17 │ #333333 │  
10 │ 17,18 │ #777777 │ \\"
10 │ 18,23 │ #448C27 │ 4.0.0
10 │ 23,24 │ #777777 │ \\"
10 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #333333 │     
11 │  4, 5 │ #777777 │ \\"
11 │  5,14 │ #9C5D27 │ package-5
11 │ 14,15 │ #777777 │ \\"
11 │ 15,16 │ #777777 │ :
11 │ 16,17 │ #333333 │  
11 │ 17,18 │ #777777 │ \\"
11 │ 18,23 │ #448C27 │ 5.0.0
11 │ 23,24 │ #777777 │ \\"
11 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #333333 │     
12 │  4, 5 │ #777777 │ \\"
12 │  5,14 │ #9C5D27 │ package-6
12 │ 14,15 │ #777777 │ \\"
12 │ 15,16 │ #777777 │ :
12 │ 16,17 │ #333333 │  
12 │ 17,18 │ #777777 │ \\"
12 │ 18,23 │ #448C27 │ 6.0.0
12 │ 23,24 │ #777777 │ \\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 2 │ #333333 │   
13 │  2, 3 │ #777777 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #777777 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/sources/json/npm-package/results/output.quiet-light.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test quiet-light theme 1`] = `
Object {
  "lines": Array [
    "[48;2;245;245;245m [38;2;109;112;91m 1 │ [39m[38;2;119;119;119m{[39m                                                                         [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 2 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mname[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39mtest-package[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 3 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mdescription[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39mSome[39m[38;2;170;170;170m·[39m[38;2;68;140;39museful[39m[38;2;170;170;170m·[39m[38;2;68;140;39mpackage[39m[38;2;170;170;170m·[39m[38;2;68;140;39mto[39m[38;2;170;170;170m·[39m[38;2;68;140;39mdo[39m[38;2;170;170;170m·[39m[38;2;68;140;39msome[39m[38;2;170;170;170m·[39m[38;2;68;140;39museful[39m[38;2;170;170;170m·[39m[38;2;68;140;39mstuff[39m[38;2;170;170;170m·[39m[38;2;68;140;39mwith[39m[38;2;170;170;170m·[39m[38;2;68;140;39madvanc…[39m[49m",
    "[48;2;245;245;245m [38;2;109;112;91m 4 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mversion[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m1.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                     [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 5 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mprivate[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;156;93;39mtrue[39m[38;2;119;119;119m,[39m                                                        [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 6 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mlicense[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39mMIT[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                       [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 7 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mdependencies[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m{[39m                                                       [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 8 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-1[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m1.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m 9 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-2[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m2.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m10 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-3[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m3.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m11 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-4[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m4.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m12 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-5[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m5.0.0[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m,[39m                                                 [49m",
    "[48;2;245;245;245m [38;2;109;112;91m13 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;156;93;39mpackage-6[39m[38;2;119;119;119m\\"[39m[38;2;119;119;119m:[39m[38;2;170;170;170m·[39m[38;2;119;119;119m\\"[39m[38;2;68;140;39m6.0.0[39m[38;2;119;119;119m\\"[39m                                                  [49m",
    "[48;2;245;245;245m [38;2;109;112;91m14 │ [39m[38;2;170;170;170m·[39m[38;2;170;170;170m·[39m[38;2;119;119;119m}[39m                                                                       [49m",
    "[48;2;245;245;245m [38;2;109;112;91m15 │ [39m[38;2;119;119;119m}[39m                                                                         [49m",
    "[48;2;245;245;245m [38;2;109;112;91m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #777777 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #333333 │   
 1 │  2, 3 │ #777777 │ \\"
 1 │  3, 7 │ #9C5D27 │ name
 1 │  7, 8 │ #777777 │ \\"
 1 │  8, 9 │ #777777 │ :
 1 │  9,10 │ #333333 │  
 1 │ 10,11 │ #777777 │ \\"
 1 │ 11,23 │ #448C27 │ test-package
 1 │ 23,24 │ #777777 │ \\"
 1 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #333333 │   
 2 │  2, 3 │ #777777 │ \\"
 2 │  3,14 │ #9C5D27 │ description
 2 │ 14,15 │ #777777 │ \\"
 2 │ 15,16 │ #777777 │ :
 2 │ 16,17 │ #333333 │  
 2 │ 17,18 │ #777777 │ \\"
 2 │ 18,89 │ #448C27 │ Some useful package to do some useful stuff with advanced capabilities.
 2 │ 89,90 │ #777777 │ \\"
 2 │ 90,91 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #333333 │   
 3 │  2, 3 │ #777777 │ \\"
 3 │  3,10 │ #9C5D27 │ version
 3 │ 10,11 │ #777777 │ \\"
 3 │ 11,12 │ #777777 │ :
 3 │ 12,13 │ #333333 │  
 3 │ 13,14 │ #777777 │ \\"
 3 │ 14,19 │ #448C27 │ 1.0.0
 3 │ 19,20 │ #777777 │ \\"
 3 │ 20,21 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #333333 │   
 4 │  2, 3 │ #777777 │ \\"
 4 │  3,10 │ #9C5D27 │ private
 4 │ 10,11 │ #777777 │ \\"
 4 │ 11,12 │ #777777 │ :
 4 │ 12,13 │ #333333 │  
 4 │ 13,17 │ #9C5D27 │ true
 4 │ 17,18 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #333333 │   
 5 │  2, 3 │ #777777 │ \\"
 5 │  3,10 │ #9C5D27 │ license
 5 │ 10,11 │ #777777 │ \\"
 5 │ 11,12 │ #777777 │ :
 5 │ 12,13 │ #333333 │  
 5 │ 13,14 │ #777777 │ \\"
 5 │ 14,17 │ #448C27 │ MIT
 5 │ 17,18 │ #777777 │ \\"
 5 │ 18,19 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #333333 │   
 6 │  2, 3 │ #777777 │ \\"
 6 │  3,15 │ #9C5D27 │ dependencies
 6 │ 15,16 │ #777777 │ \\"
 6 │ 16,17 │ #777777 │ :
 6 │ 17,18 │ #333333 │  
 6 │ 18,19 │ #777777 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #333333 │     
 7 │  4, 5 │ #777777 │ \\"
 7 │  5,14 │ #9C5D27 │ package-1
 7 │ 14,15 │ #777777 │ \\"
 7 │ 15,16 │ #777777 │ :
 7 │ 16,17 │ #333333 │  
 7 │ 17,18 │ #777777 │ \\"
 7 │ 18,23 │ #448C27 │ 1.0.0
 7 │ 23,24 │ #777777 │ \\"
 7 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #333333 │     
 8 │  4, 5 │ #777777 │ \\"
 8 │  5,14 │ #9C5D27 │ package-2
 8 │ 14,15 │ #777777 │ \\"
 8 │ 15,16 │ #777777 │ :
 8 │ 16,17 │ #333333 │  
 8 │ 17,18 │ #777777 │ \\"
 8 │ 18,23 │ #448C27 │ 2.0.0
 8 │ 23,24 │ #777777 │ \\"
 8 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #333333 │     
 9 │  4, 5 │ #777777 │ \\"
 9 │  5,14 │ #9C5D27 │ package-3
 9 │ 14,15 │ #777777 │ \\"
 9 │ 15,16 │ #777777 │ :
 9 │ 16,17 │ #333333 │  
 9 │ 17,18 │ #777777 │ \\"
 9 │ 18,23 │ #448C27 │ 3.0.0
 9 │ 23,24 │ #777777 │ \\"
 9 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #333333 │     
10 │  4, 5 │ #777777 │ \\"
10 │  5,14 │ #9C5D27 │ package-4
10 │ 14,15 │ #777777 │ \\"
10 │ 15,16 │ #777777 │ :
10 │ 16,17 │ #333333 │  
10 │ 17,18 │ #777777 │ \\"
10 │ 18,23 │ #448C27 │ 4.0.0
10 │ 23,24 │ #777777 │ \\"
10 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #333333 │     
11 │  4, 5 │ #777777 │ \\"
11 │  5,14 │ #9C5D27 │ package-5
11 │ 14,15 │ #777777 │ \\"
11 │ 15,16 │ #777777 │ :
11 │ 16,17 │ #333333 │  
11 │ 17,18 │ #777777 │ \\"
11 │ 18,23 │ #448C27 │ 5.0.0
11 │ 23,24 │ #777777 │ \\"
11 │ 24,25 │ #777777 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #333333 │     
12 │  4, 5 │ #777777 │ \\"
12 │  5,14 │ #9C5D27 │ package-6
12 │ 14,15 │ #777777 │ \\"
12 │ 15,16 │ #777777 │ :
12 │ 16,17 │ #333333 │  
12 │ 17,18 │ #777777 │ \\"
12 │ 18,23 │ #448C27 │ 6.0.0
12 │ 23,24 │ #777777 │ \\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 2 │ #333333 │   
13 │  2, 3 │ #777777 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #777777 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;
